@@ -145,7 +145,7 @@ impl Qoi {
                                     // this produces valid QOI and have the exactly same size.
                                     // Decoding is slightly faster.
                                     let index_pos = px_prev.hash();
-                                    rest[0] = QOI_OP_INDEX | index_pos as u8;
+                                    rest[0] = QOI_OP_INDEX | index_pos;
                                     rest = &mut rest[1..];
                                     *run = 0;
                                 }
@@ -238,8 +238,13 @@ impl Qoi {
     pub fn encode_alloc(&self, pixels: &[u8]) -> Result<Vec<u8>, EncodeError> {
         let limit = self.encoded_size_limit();
         let mut output = vec![0; limit];
-        let size = self.encode(pixels, &mut output)?;
-        output.truncate(size);
-        Ok(output)
+        match self.encode(pixels, &mut output) {
+            Ok(size) => {
+                output.truncate(size);
+                Ok(output)
+            }
+            Err(EncodeError::OutputIsTooSmall) => unreachable(),
+            Err(err) => Err(err),
+        }
     }
 }
