@@ -330,12 +330,19 @@ impl Pixel for Rgb {
     }
 
     #[inline]
+    #[cfg(target_endian = "big")]
     fn hash(&self) -> u8 {
         let [r, g, b] = self.rgb;
-        r.wrapping_mul(3)
-            .wrapping_add(g.wrapping_mul(5))
-            .wrapping_add(b.wrapping_mul(7).wrapping_add(245))
-            & 63
+        let h = u32::from_ne_bytes([r, g, b, 0]).wrapping_mul(0x00070503);
+        h.to_be_bytes()[0] & 63
+    }
+
+    #[inline]
+    #[cfg(target_endian = "little")]
+    fn hash(&self) -> u8 {
+        let [r, g, b] = self.rgb;
+        let h = u32::from_ne_bytes([r, g, b, 0]).wrapping_mul(0x03050700);
+        h.to_be_bytes()[0] & 63
     }
 }
 
@@ -457,12 +464,17 @@ impl Pixel for Rgba {
     }
 
     #[inline]
+    #[cfg(target_endian = "big")]
     fn hash(&self) -> u8 {
-        let [r, g, b, a] = self.rgba;
-        r.wrapping_mul(3)
-            .wrapping_add(g.wrapping_mul(5))
-            .wrapping_add(b.wrapping_mul(7).wrapping_add(a.wrapping_mul(11)))
-            & 63
+        let h = u32::from_ne_bytes(self.rgba).wrapping_mul(0x0b070503);
+        h.to_be_bytes()[0] & 63
+    }
+
+    #[inline]
+    #[cfg(target_endian = "little")]
+    fn hash(&self) -> u8 {
+        let h = u32::from_ne_bytes(self.rgba).wrapping_mul(0x0305070b);
+        h.to_be_bytes()[0] & 63
     }
 }
 
